<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>RecentFiles</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">ロード/セーブ</translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translation>最近使ったファイル</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translation>&amp;C リストをクリア</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;Recent</source>
        <translation>&amp;R 最近使ったファイルを開く</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation>最近使用したファイル履歴の保存数:</translation>
    </message>
</context>
</TS>
